/*
 * share/config.h
 *
 * Copyright 2004, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#ifndef share_config_h
#define share_config_h


#define MAX_CPU 8								/* 対応最大cpu数 */


#endif
